@@ -26,7 +26,7 @@ BEGIN	{
 
 	*warn = \&{CGI::Carp::warn};
 	*carpout = \&{CGI::Carp::carpout};
-	$main::SIG{'__DIE__'}='CGI::Out::fakedie';
+	$main::SIG{'__DIE__'}= \&CGI::Out::fakedie;
 
 	$out = '';
 	@saveA = @ARGV;
